function getLanguage(){
    var locale= getFromPropertyTree("/system/language/locale","",false);
    var re = /^de\_.*/;
    if (re.test(locale)){
	return "de";
    }else{
	return "en";
    }
}


function createNotificationList(param){
    /* callback function for the cloudService.fetchNotificationList:function(func).

       This function stores the smart phones list to the property
       tree.
    */

    var token=cloudService.getOSPToken();

    if (token !== null && token !== undefined){
	var MobileApps = param.Response.MobileApps;
	var Devices=[];


	for (var dev in MobileApps){
	    var Name=MobileApps[dev]["MobileName"];
	    var uuid=MobileApps[dev]["MobileAppUUID"];

	    Devices.push({"name":Name,"UUID":uuid});
	}

	saveToPropertyTree("Notifications/PushTargetOptions",JSON.stringify(Devices),true);
    }
}



function sendEmailFilterReplacement(){
    var lang=getLanguage();
    // get Email address
    var Recipient=getFromPropertyTree("Notifications/EmailAddress","",false);
    // decode message

    var EmailBody={"de": "Ein Filterwechsel der Airboxen ist fällig. Woher Sie einen neuen Filter bekommen:  Falls Sie kein Filter- oder Serviceabo haben,  können Sie einen neuen Filterunter filter@wesco.ch bestellen. Bitte wechseln Sie den Filter gemäss Bedienungsanleitung und entsorgen Sie den gebrauchten Filter im Hausmüll.    Die nächste Filterwechsel ist in einem Jahr fällig.  Sie werden eine Benachrichtigung erhalten.", "en":"The Airboxes's filters have to be replaced.  In case you do not have any spare filters or Serviceabo,  you can order new filters from filter@wesco.ch. Please change the filter(s) according to the instructions in the user manual and dispose the old one(s).  The next filter replacement is due in one year time.  You will receive a reminder per email."};

    var Subject={"de":"dSS-Benachrichtigung (Filterwechsel)","en":"dSS-Notification (Ariboxes' filter replacement)"};

    try{
	var evt = new Event("wesco_eventmailerexecute",{'to':Recipient,'body':EmailBody[lang],'subject':Subject[lang],'from':'dSS-Benachrichtigung'});
	evt.raise();
    }
    catch(err){
	//todo
    }
} // end ... function sendEmailFilterReplacement(){


function sendEmailError(ErrorCode,dSID){
    /*This function sends an Email notifying about an error defined by
     * ErrorCode in the airbox identified by dSID.

     ErrorCodes are defined in constants.js
     */

    var lang=getLanguage();
    var errors={};
    errors[ErrorCodes["power_error"]]={"de":"Spannungsstörung","en":"Power error"};
    errors[ErrorCodes["fan_error"]]={"de":"Ventilatorstörung","en":"Fan error"};
    errors[ErrorCodes["sensor_error"]]={"de":"Sensorstörung","en":"Sensor error"};
    errors[ErrorCodes["frost_error"]]={"de":"Frostfehler","en":"Frost error"};
    errors[ErrorCodes["timeout_error"]]={"de":"Airbox nicht erreichbar","en":"Airbox unreachable"};

    function getEmailMessage(ErrorCode,dSID){
	/*This function prepares the message to be sent by Email, which
	 * describes a given error*/

	var DeviceName=getDevices().byDSID(dSID).name;

	// error definition in German

	var causes={};
	causes[ErrorCodes["power_error"]]={"de":"Problem in der Stromversorgung.","en":"problem with the power supply."};
	causes[ErrorCodes["fan_error"]]={"de":"verschmutzer oder defekter Ventilator.","en":"dirty or defective fan."};
	causes[ErrorCodes["sensor_error"]]={"de":"defekter Temperatursensor.","en":"defective temperature sensor."};
	causes[ErrorCodes["frost_error"]]={"de":"unzureichende Wärmeversorgung.","en":"insufficient heat supply."};
	causes[ErrorCodes["timeout_error"]]={"de":"keine Verbindung zur Airbox.","en":"there is not communication with the Airbox."};

	var action1={"de":" Versuchen Sie folgende Massnahmen,  welche detailliert in der Bedinungsanleitung beschrieben sind.","en":" Please follow the instructions detailed in the user manual."};

	var action2={"de":"Starten Sie die Airbox neu. Schalten Sie dazu die der Airbox zugeordnete Sicherung im Sicherungskasten aus,  warten Sie 2 Minuten und schalten dann die Sicherung wieder ein. Die Airbox benötigt einige Minuten um sich wieder im System anzumelden. Aktualizieren Sie  die Airboxen auf den Benützeroberfläche.","en":"Re-start the Airbox. Turn off  the corresponding fuse in the fuse box,  wait 2 minutes and turn it on again. The Airbox takes some minutes before it registers in the system. Update the Airboxes at the user interface."};


	//Einleitung


	var message='';

	if (lang=="de"){
	    message="Die Lüftungs-App meldet eine ";
	    message+="\""+errors[ErrorCode][lang]+"\"";
	    message+=" auf der Airbox \""+DeviceName+"\" ("+dSID+").";
	    message+=" Leider konnte der Fehler nicht automatisch behoben werden.\nMögliche Ursache(n) für den Fehler: ";
	    message+=causes[ErrorCode][lang]; //Ursachen

	    if (ErrorCode == ErrorCodes["timeout_error"]){
		message+=action2[lang];
	    }else{
		message+=action1[lang];
	    }
	    message+=" Falls der Fehler trotz der Massnahmen immer noch auftritt, kontaktieren Sie die Hauswartung."
	}
 	else{
	    message="The Airbox-add-on reports a ";
	    message+="\""+errors[ErrorCode][lang]+"\"";
	    message+=" in  Airbox \""+DeviceName+"\" ("+dSID+").";
	    message+=" Unfortunately,  it was not possible to automatically remove this error. Possible causes are: ";
	    message+=causes[ErrorCode][lang]; //Ursachen

	    if (ErrorCode == ErrorCodes["timeout_error"]){
		message+=action2[lang];
	    }else{
		message+=action1[lang];
	    }
	    message+=" In case the error persists after the previously described  measures,  please contact  the housekeeper."
	}

	return message;
    } // end ... function getEmailMessage(ErrorCode,dSID){

    // get Email address
    var Recipient=getFromPropertyTree("Notifications/EmailAddress","",false);
    // decode message

    var EmailBody=getEmailMessage(ErrorCode,dSID);
    var Subject={"de":"dSS-Benachrichtigung ("+errors[ErrorCode][lang]+")","en":"dSS-Notification ("+errors[ErrorCode][lang]+")"};

    try{
	if(Recipient!==undefined && Recipient != DEFAULT_STRING){
	    var evt = new Event("wesco_eventmailerexecute",{'to':Recipient,'body':EmailBody,'subject':Subject[lang],'from':'dSS-Benachrichtigung'});
	    evt.raise();
	}
    }
    catch(err){
	//report error: email can not be sent
    }
}





function sendPushNotification(Type){
    /* This function sends a push notification to the mobile devices
     * registered at the dSS.  Type is either "Error" or "FilterReplacement"*/

    function getNotificationMessage(Type){
	/*This function returns a generic notification error*/;


	var lang=getLanguage();

	var messages;

	switch(Type){
	case "FilterReplacement":
	    messages = {"de":"Bitte die Filtern aller Airboxen auswechseln!",
			"en": "Please replace the Airboxes filters"};
	    break;
	default:
	    messages = {"de":"Airbox Fehler, schauen Sie bitte auf unsere Webpage!",
			"en": "Airbox error, please check the webpage!"};
	    break;
	}

	return messages[lang];
    }

    try{
	var token=cloudService.getOSPToken();

	var Devices=getFromPropertyTree("Notifications/PushTargets","",false);
	var Message=getNotificationMessage(Type);

	if (token !== null && token !== undefined){
	    if(Devices!==undefined){

		cloudService.sendNotification(JSON.parse(Devices),Message);

	    }
	}
    }// end ... try
    catch(err){
	debug("DEBUG","Notification cannot be sent");
	//report error: can not send push notification
    }

}
