
function getFromPropertyTree(path,default_value,create){
    /*
      This function retrieves a variable from the property tree. If
      the variable does not exist and the flag create is true, a new
      variable is created with value default_value.

      returns the read variable or undefined
    */

    var myvar=Property.getProperty(path);

    if ((myvar === null||myvar === undefined)) {
	if (create){
	    myvar=default_value;
	    Property.setProperty(path,myvar);
    	    Property.setFlag(path, 'ARCHIVE', true); //set ARCHIVE flag to active
	    Property.store();

	}else{
	    return undefined; // variable does not exist and will not be created
	}
    }

    return myvar;
}


function setArchiveFlag(path){
    Property.setFlag(path, 'ARCHIVE', true); //set ARCHIVE flag to active
    Property.store();
}

function saveToPropertyTree(path,var_value,create){
    /*
      This function stores a value to the property tree.

      path is the variable's  relative path

      create is a boolean. When true,  the variable is created if it did not exist before.
      When false,  the variable is only stored if it existed previously.

    */

    var myvar=Property.getProperty(path);

    if (myvar === null || myvar === undefined) {
	if (create){
	    Property.setProperty(path,var_value);
	    Property.setFlag(path, 'ARCHIVE', true); //set flag to active
	    Property.store();
	}
    }else{
	Property.setProperty(path,var_value);
	Property.store();
    }
}


function initializePropertyTree(){
    /*
      This function retrieves all the required variables from the
      property tree.  Non-existent variables are created and assigned
      a default value.
    */


    //Notifications
    var Devices=[];


    getFromPropertyTree("Notifications/PushTargets",JSON.stringify(Devices),true);
    getFromPropertyTree("Notifications/PushTargetOptions",JSON.stringify(Devices),true);
    getFromPropertyTree("Notifications/EmailAddress",DEFAULT_STRING,true);


    // Controller
    //getFromPropertyTree("Controller/ClusterID",16,true);
    saveToPropertyTree("Controller/ClusterID",19,true); // has to be created dynamically
    getFromPropertyTree("Controller/CurrentLevel",DEFAULT_INT,true);

    // Exhaust flap
    getFromPropertyTree("ExhaustFlap",DEFAULT_STRING,true);
    //saveToPropertyTree("ExhaustFlap",DEFAULT_STRING,true);


    //Airboxes FilterReplacementInterval in [day]
    getFromPropertyTree("Airboxes/FilterReplacementInterval",FilterReplacementInterval,true); //365
    //saveToPropertyTree("Airboxes/FilterReplacementInterval",3,true); //365

    var dateReplacement=new Date();
    getFromPropertyTree("Airboxes/LastFilterReplacementDate",dateReplacement.toISOString(),true);

    //Prevent that app be uninstalled (????)
    saveToPropertyTree("system/preventUninstall",true,true);

    debug("DEBUG","Loaded property tree");
}
