/*
controllers.js
Angular module that provides the main and only controller for the wesco airbox app
*/

var airboxControllers = angular.module('airboxControllers', ['airboxDSS','dSS']);

airboxControllers.controller('OverviewCtrl', ['$q','$scope','$timeout','airboxDSS','dss',
	function($q,$scope,$timeout,airboxDSS,dss) {

	// Global ajax error message to display
	$scope.ajaxError = false;

	// Ajax request states to show/hide elements depending on if content is loaded
	$scope.ajax = {
		'levelReady': false,
		'settingLevel': false,
		'settingConfig': false,
		'exhaustFlapCandidatesReady': false,
		'pushTargetOptionsReady': false,
		'configReady': false,
		'errorlogReady': false,
		'deviceListReady': false,
	};

	// Variables for pagination of logfiles
	$scope.logTable = {
		'maxSize' : 10,
		'currentPage' : 1,
	};

	// Translations of error texts
	$scope.airbox_error_texts = {
		'NOERROR':'OK',
		'POWERERR':'Spannungsstörung',
		'SENSORERR':'Sensorstörung',
		'FANERR':'Ventilatorstörung',
		'FLAPERR':'Klappenstörung',
		'FROSTERR':'Froststörung',
		'FROSTWAR':'Frostwarnung',
		'NEWAIRBOX':'Neue Airbox erkannt',
		'AIRBOXLOST':'Airbox nicht mehr vorhanden',
		'TIMEOUTERR':'Verbindungsfehler',
	};

	$scope.refreshCurrentLevel = function() {
		$scope.ajax.levelReady = false;
		return airboxDSS.getCurrentLevel().then(function(currentLevel) {
			$scope.currentLevel = currentLevel;
			$scope.ajax.levelReady = true;
		});
	};

	$scope.refreshConfig = function() {
		$scope.ajax.configReady = false;
		return airboxDSS.getConfig().then(function(config) {
			$scope.config = config;
			$scope.selectedPushTargets = {};
			for (var i = 0; i < $scope.config.PushTargets.length; i++) {
				$scope.selectedPushTargets[$scope.config.PushTargets[i]] = true;
			}
			$scope.ajax.configReady = true;
		});
	};

	$scope.refreshErrorLog = function() {
		$scope.ajax.errorlogReady = false;
		return airboxDSS.getErrorLog().then(function(errorlog) {
			$scope.errorLog = [];
			for (var i = 0; i < errorlog.length; i++) {
				$scope.errorLog.push({
					'datetime':errorlog[i][0],
					'type':errorlog[i][1],
					'dSUID':errorlog[i][2],
					'name':$scope.Airboxes.nameById[errorlog[i][2]]?$scope.Airboxes.nameById[errorlog[i][2]]:errorlog[i][2],
					'errorcode':errorlog[i][3],
				});
			}

			$scope.ajax.errorlogReady = true;
		});
	};

	$scope.refreshExhaustFlapCandidates = function() {
		$scope.ajax.exhaustFlapCandidatesReady = false;
		return airboxDSS.getExhaustFlapCandidates().then(function(devlist) {
			$scope.exhaustFlapCandidates = devlist;
			$scope.ajax.exhaustFlapCandidatesReady = true;
		})
	};

	$scope.refreshPushTargetOptions = function() {
		$scope.ajax.pushTargetOptionsReady = false;
		return airboxDSS.refreshPushTargetOptions().then(function() {
			return $timeout(function() {
				return airboxDSS.getPushTargetOptions().then(function(targets) {
					$scope.pushTargetOptions = targets;
					$scope.ajax.pushTargetOptionsReady = true;
				})
			},3000);
		});
	};

	$scope.clearAllAirboxErrors = function() {
		var answer = confirm("Wenn die Störung weiterhin besteht ist dies nach dem Entfernen der Störungsmeldungen nicht sofort ersichtlich. Bitte überprüfen Sie in 30 Minuten ob der Fehler nun behoben ist.")
		if (!answer) {
			$scope.refreshConfig();
			return;
		}

		$scope.ajax.deviceListReady = false;
		return airboxDSS.clearAllAirboxErrors().then(function() {
			return $timeout(function() {
				return $scope.refreshAirboxes();
			},3000);
		});
	};

	$scope.updateConfig = function() {
		var answer = confirm("Sind Sie sicher, dass sie Konfiguration ändern möchten?")
		if (!answer) {
			$scope.refreshConfig();
			return;
		}

		var promises = [];
		$scope.ajax.settingConfig = false;

		// Create list of selected UUIDs
		$scope.config.PushTargets = [];
		for (var UUID in $scope.selectedPushTargets) {
			if ($scope.selectedPushTargets.hasOwnProperty(UUID)) {
				if($scope.selectedPushTargets[UUID]) {
					$scope.config.PushTargets.push(UUID);
				}
			}
		}

		promises.push(airboxDSS.setPushTargets($scope.config.PushTargets));
		promises.push(airboxDSS.setExhaustFlap($scope.config.ExhaustFlap));
	    promises.push(airboxDSS.setEmailAddress($scope.config.EmailAddress));

	    //@Diego
	    promises.push(dss.Scene.disableScene($scope.config.ExhaustFlap,72)); // Scene 72 -> leave home
	    promises.push(dss.Scene.disableScene($scope.config.ExhaustFlap,69)); // Scene 69 -> sleeping
	    promises.push(airboxDSS.storeConfigurableParameters());


		return $q.all(promises).then(function() {
			$scope.ajax.settingConfig = true;
		});
	};

	$scope.refreshAirboxes = function() {
		var promises = [];
		if(typeof $scope['Airboxes'] == 'undefined') {
			$scope['Airboxes'] = {
				'nameById': {},
			};
		}
		$scope.ajax.deviceListReady = false;
		airboxDSS.rediscoverAirboxes();
		// Wait 5 seconds for background script to update property tree
		return $timeout(function() {
			promises.push(airboxDSS.getAirboxConfig().then(function(config) {
				for (var attrname in config) {
					$scope['Airboxes'][attrname] = config[attrname];
				}
			}));
			promises.push(airboxDSS.getAirboxes().then(function(airboxes) {
				$scope.Airboxes.Devices = airboxes;
				$scope.Airboxes.Error = false;
				// Create index to resolve name by dSUID
				for (var i = 0; i < $scope.Airboxes.Devices.length; i++) {
					if($scope.Airboxes.Devices[i].errorcode!='NOERROR') {
						$scope.Airboxes.Error = true;
					}
					$scope.Airboxes.nameById[$scope.Airboxes.Devices[i].dSUID] = $scope.Airboxes.Devices[i].Description;
				};
			}));
			return $q.all(promises).then(function() {
				$scope.ajax.deviceListReady = true;
			});
		},3000);
	};

	$scope.setLevel = function(level) {
		$scope.ajax.settingLevel = true;
		airboxDSS.setLevel($scope.config.ClusterID,level).then(function() {
			$scope.ajax.settingLevel = false;
		});
	};

	$scope.initDSS = function() {
		// get locale, if german set ui to german otherwise use english
		return dss.Property.getString("/system/language/locale").then(function(locale) {
			if(locale.substr(0,2)=="de") {

			}
		});
	}

	$scope.loadAll = function() {
		var promises = [];
		promises.push($scope.initDSS());
		promises.push($scope.refreshConfig());
		promises.push($scope.refreshAirboxes());
		promises.push($scope.refreshExhaustFlapCandidates());
		promises.push($scope.refreshPushTargetOptions());
		return $q.all(promises);
	};
 	(function pollLevel() {
 		$scope.refreshCurrentLevel().then(function() {
            $timeout(pollLevel, 3000);
        });
    })();
	$scope.loadAll().then(function() {
		return $scope.refreshErrorLog();
	},
	function(err) {
		$scope.ajaxError = err;
		console.log(err);
	});

}]);
